@@ -36,7 +36,7 @@ def writeable_dir(prospective_dir):
         raise argparse.ArgumentTypeError("writeable_dir:{0} is not a writeable dir".format(prospective_dir))
 
 def parse_args():
-    parser = argparse.ArgumentParser(prog='OrthoNeighborhood', description='Track Synteny of Orthologs Across Genomes')
+    parser = argparse.ArgumentParser(prog='Vicinator', description='Track Microsynteny of a target proteins and its orthologs across genomes')
 
     parser.add_argument('--tabular-ortholog-groups', dest='ogtable', metavar='<orthology_table>',
                         type=argparse.FileType('rt'), #required=True,
@@ -73,7 +73,7 @@ def parse_args():
                         default=None,
                         help='Optional mapping file feature file accession <tabs> replacement string')
 
-    parser.add_argument('--version', action='version', version='0.0.1')
+    parser.add_argument('--version', action='version', version='0.0.5')
 
 
     return parser.parse_args()
